@@ -1,7 +1,3 @@
-from pathlib import Path
-from typing import Union
-
-import toml
 from pika import PlainCredentials, ConnectionParameters
 
 
@@ -18,13 +14,6 @@ class RabbitConfig:
         self.credentials = credentials
         self.params = ConnectionParameters(host, port, '/', self.credentials)
 
-    @staticmethod
-    def from_toml_file(path: Union[Path, str]) -> 'RabbitConfig':
-        if isinstance(path, str):
-            path = Path(path)
-        data = toml.load(path)['rabbit']
-        return RabbitConfig.from_dict(data)
-
     @staticmethod
     def from_dict(dictionary: dict[str, any]) -> 'RabbitConfig':
         host = dictionary['host']
